/*
 * Fabric3
 * Copyright (c) 2009 Metaform Systems
 *
 * Fabric3 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version, with the
 * following exception:
 *
 * Linking this software statically or dynamically with other
 * modules is making a combined work based on this software.
 * Thus, the terms and conditions of the GNU General Public
 * License cover the whole combination.
 *
 * As a special exception, the copyright holders of this software
 * give you permission to link this software with independent
 * modules to produce an executable, regardless of the license
 * terms of these independent modules, and to copy and distribute
 * the resulting executable under terms of your choice, provided
 * that you also meet, for each linked independent module, the
 * terms and conditions of the license of that module. An
 * independent module is a module which is not derived from or
 * based on this software. If you modify this software, you may
 * extend this exception to your version of the software, but
 * you are not obligated to do so. If you do not wish to do so,
 * delete this exception statement from your version.
 *
 * Fabric3 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the
 * GNU General Public License along with Fabric3.
 * If not, see <http://www.gnu.org/licenses/>.
 *
 * ----------------------------------------------------
 *
 * Portions originally based on Apache Tuscany 2007
 * licensed under the Apache 2.0 license.
 *
 */
package org.fabric3.model.type.definitions;

import javax.xml.namespace.QName;

import org.fabric3.model.type.ModelObject;

/**
 * Base policy definition type.
 *
 * @version $Rev: 8513 $ $Date: 2010-01-05 16:00:13 +0100 (Tue, 05 Jan 2010) $
 */
public abstract class AbstractPolicyDefinition extends ModelObject {
    private static final long serialVersionUID = -4450566760116409021L;

    private final QName name;

    /**
     * Constructor.
     *
     * @param name qualified mame of the definition object.
     */
    public AbstractPolicyDefinition(QName name) {
        this.name = name;
    }

    /**
     * Returns the qualified name of the definition.
     *
     * @return the qualified name of the definition
     */
    public final QName getName() {
        return name;
    }

    @Override
    public boolean equals(Object other) {
        return other != null && this.getClass() == other.getClass() && ((AbstractPolicyDefinition) other).name.equals(name);
    }

    @Override
    public int hashCode() {
        return name.hashCode();
    }

    @Override
    public String toString() {
        return name.toString();
    }

}
